==> haskell-jose-0.7.0.0-98-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.7.0.0
id: jose-0.7.0.0-7VcjqTVQbL28k68TXY1cA9
key: jose-0.7.0.0-7VcjqTVQbL28k68TXY1cA9
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016, 2017  Fraser Tweedale
maintainer: frase@frase.id.au
author: Fraser Tweedale
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    .
    EdDSA signatures (RFC 8037) are supported (Ed25519 only).
    .
    JWK Thumbprint (RFC 7638) is supported (requires /aeson/ >= 0.10).
    .
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.
category: Cryptography
abi: 063291560681f120dd99d15325de3450
exposed: True
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/jose-0.7.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/jose-0.7.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/jose-0.7.0.0
hs-libraries: HSjose-0.7.0.0-7VcjqTVQbL28k68TXY1cA9
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.3.0-5u6hknCeN6OEP5DlN5W0LL
    attoparsec-0.13.2.2-FR6Av5BO2dBDiw4NtrzSsH base-4.12.0.0
    base64-bytestring-1.0.0.2-9hYbO3I2I9012gU046eVdX
    bytestring-0.10.8.2 concise-0.1.0.1-JEJLdBUZ1HBLGK5kkyPySN
    containers-0.6.0.1 cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    lens-4.17.1-Ii3Qh0jlmopECfPGkUKRMA
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    monad-time-0.3.1.0-9WsuLBKAlPL3yTdJ9sJWEr mtl-2.2.2
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    quickcheck-instances-0.3.19-BmmP2qBZRqbHVf5R538za
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    x509-1.7.5-2xExHLJ3VNlBZRhBywKbfo
haddock-interfaces: /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jose-0.7.0.0-101-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.7.0.0
id: jose-0.7.0.0-4yPDc0x8mm8GJVMFD67z8x
key: jose-0.7.0.0-4yPDc0x8mm8GJVMFD67z8x
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016, 2017  Fraser Tweedale
maintainer: frase@frase.id.au
author: Fraser Tweedale
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    .
    EdDSA signatures (RFC 8037) are supported (Ed25519 only).
    .
    JWK Thumbprint (RFC 7638) is supported (requires /aeson/ >= 0.10).
    .
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.
category: Cryptography
abi: b81af6eb3a30262eef84ab6a63cf0378
exposed: True
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/jose-0.7.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/jose-0.7.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/jose-0.7.0.0
hs-libraries: HSjose-0.7.0.0-4yPDc0x8mm8GJVMFD67z8x
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.3.0-1l3nsKlFRrWAit5U2tQl5L
    attoparsec-0.13.2.2-IaNz9bz10S32KGLwZomjal base-4.12.0.0
    base64-bytestring-1.0.0.2-9hYbO3I2I9012gU046eVdX
    bytestring-0.10.8.2 concise-0.1.0.1-IGB68QAyRchGMeFUsGYDR0
    containers-0.6.0.1 cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    lens-4.17.1-D6OjOdeP0MqEPqDMoHvH3T
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    monad-time-0.3.1.0-9WsuLBKAlPL3yTdJ9sJWEr mtl-2.2.2
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    quickcheck-instances-0.3.19-51f4TnfQCjvL50uCF0VJyX
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    x509-1.7.5-CTIlogbzSX5AoCOzcpZ4iY
haddock-interfaces: /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
